%if 0%{?_version:1}
%define _verstr      %{_version}
%else
%define _verstr      0.0.23
%endif

# puppetserver still runs a ruby 1.9.3 kind JRuby
%define gems trocla iuid base32 ip formatador systemu hashdiff open4 acme-client public_suffix ed25519
# we don't need sinatra oder openoffice in jruby
%define mrionly_gems sinatra roo simpleidn sha3
# we want the jruby version of pg
%define jrubyonly_gems sha3-pure-ruby

%define checkout %(date +%Y%m%d)

%define agentdir /opt/puppetlabs/puppet
%define agentgemdir %{agentdir}/lib/ruby/gems/2.7.0/
%define servergemdir /opt/puppetlabs/server/data/puppetserver/jruby-gems

Name:		puppet-extensions
Version:	%{_verstr}
Release:	1
Summary:	Extension for the puppet-agent or puppetserver.
License:	GPLv3
Source0: puppetserver.conf
Patch0: https://github.com/duritong/ip/commit/0cf261fa2fb75113c94fef5ac231f3d7b2f3ff4c.patch

BuildRequires: puppet-agent >= 7.7
BuildRequires: puppetserver >= 7.2
%if 0%{?rhel} >= 8
BuildRequires: postgresql
BuildRequires: postgresql-devel
%else
BuildRequires: postgresql13
BuildRequires: postgresql13-devel
%endif
BuildRequires: libxml2-devel
BuildRequires: libxslt-devel
BuildRequires: gcc-c++
BuildRequires: chrpath
Requires: puppet-agent >= 7.7

%description

A set of gems for puppet agent & server


%filter_requires_in %agentgemdir
%filter_setup

%package -n puppet-agent-extensions
Summary:	Extension for the puppet-agent.
Requires: puppet-agent >= 7.0
%description -n puppet-agent-extensions

A set of gem extensions packaged for the puppet-agent.

%package -n puppetserver-extensions
Summary:	Extension for the puppetserver.
Requires: puppetserver >= 7.0
%description -n puppetserver-extensions

A set of gem extensions packaged for the puppetserver.

%prep

mkdir server_config
cp %{SOURCE0} server_config
mkdir -p ~/.puppetlabs/etc/puppet
echo -e "[master]\nconfdir=~/puppet\ncodedir=~/puppetcode" > ~/.puppetlabs/etc/puppet/puppet.conf

%build

export PATH=$PATH:/usr/pgsql-13/bin
/opt/puppetlabs/puppet/bin/gem install --lock --install-dir ./agent_gems --no-document -N %{gems} %{mrionly_gems}

# so it picks up the right config
export JAVA_BIN=/usr/bin/java
export JAVA_ARGS='-Xms2g -Xmx2g -Djruby.logger.class=com.puppetlabs.jruby_utils.jruby.Slf4jLogger'
export USER=puppet
export GROUP=puppet
export INSTALL_DIR=/opt/puppetlabs/server/apps/puppetserver
export SERVICE_STOP_RETRIES=60
export START_TIMEOUT=300
export RELOAD_TIMEOUT=120
export CLASSPATH=${INSTALL_DIR}/puppet-server-release.jar
export JRUBY_JAR="${JRUBY_JAR:-${INSTALL_DIR}/jruby-9k.jar}"
export CLASSPATH="${CLASSPATH}:${JRUBY_JAR}"
export CONFIG=./server_config
"${JAVA_BIN}" $JAVA_ARGS_CLI -Djava.security.egd=/dev/urandom \
    -cp "$CLASSPATH" \
    clojure.main -m puppetlabs.puppetserver.cli.gem \
     --config ./server_config -- install --lock --install-dir ./server_gems --no-document -N %{gems} %{jrubyonly_gems}

cd ./agent_gems/gems/ip-*
patch -p1 < %{PATCH0}
cd ../../../
cd ./server_gems/gems/ip-*
patch -p1 < %{PATCH0}
cd ../../../

# remove unused files with broken shebang
rm -rf ./agent_gems/gems/*/gems/rack-*/test/
rm -rf ./server_gems/gems/rack-*/test

for gem in $(find %{agentgemdir}/gems -mindepth 1 -maxdepth 1 -type d -exec basename {} \;) ; do
  find ./agent_gems/ -maxdepth 2 -name "${gem}*" -exec rm -rf {} \;
done

for gem in $(find %{servergemdir}/gems -mindepth 1 -maxdepth 1 -type d -exec basename {} \;) ; do
  find ./server_gems/ -maxdepth 2 -name "${gem}*" -exec rm -rf {} \;
done

%install

# racc is already present by puppet itself
rm ./*/bin/racc

mkdir -p %{buildroot}%{agentgemdir}
for d in specifications gems extensions; do
  mv ./agent_gems/${d} %{buildroot}%{agentgemdir}/
done
mv ./agent_gems/bin %{buildroot}%{agentdir}/bin

mkdir -p %{buildroot}%{servergemdir}
for d in bin specifications gems; do
  mv ./server_gems/${d} %{buildroot}%{servergemdir}/
done

chrpath -d %{buildroot}/opt/puppetlabs/puppet/lib/ruby/gems/*/extensions/x86_64-linux/*/bcrypt-*/bcrypt_ext.so
chrpath -d %{buildroot}/opt/puppetlabs/puppet/lib/ruby/gems/*/extensions/x86_64-linux/*/unf_ext-*/unf_ext.so
chrpath -d %{buildroot}/opt/puppetlabs/puppet/lib/ruby/gems/*/extensions/x86_64-linux/*/ed25519-*/ed25519_ref10.so
chrpath -d %{buildroot}/opt/puppetlabs/puppet/lib/ruby/gems/*/extensions/x86_64-linux/*/sha3-*/sha3_n.so
chrpath -d %{buildroot}/opt/puppetlabs/puppet/lib/ruby/gems/*/extensions/x86_64-linux/*/*/racc/cparse.so

chrpath -d %{buildroot}/opt/puppetlabs/puppet/lib/ruby/gems/*/gems/bcrypt-*/ext/mri/bcrypt_ext.so
chrpath -d %{buildroot}/opt/puppetlabs/puppet/lib/ruby/gems/*/gems/bcrypt-*/lib/bcrypt_ext.so
chrpath -d %{buildroot}/opt/puppetlabs/puppet/lib/ruby/gems/*/gems/nokogiri-*/lib/nokogiri/*/nokogiri.so
chrpath -d %{buildroot}/opt/puppetlabs/puppet/lib/ruby/gems/*/gems/unf_ext-*/ext/unf_ext/unf_ext.so
chrpath -d %{buildroot}/opt/puppetlabs/puppet/lib/ruby/gems/*/gems/unf_ext-*/lib/unf_ext.so
chrpath -d %{buildroot}/opt/puppetlabs/puppet/lib/ruby/gems/*/gems/racc-*/ext/racc/cparse/cparse.so
chrpath -d %{buildroot}/opt/puppetlabs/puppet/lib/ruby/gems/*/gems/racc-*/lib/racc/cparse.so

chrpath -d %{buildroot}/opt/puppetlabs/puppet/lib/ruby/gems/*/gems/ed25519-*/ext/ed25519_ref10/ed25519_ref10.so
chrpath -d %{buildroot}/opt/puppetlabs/puppet/lib/ruby/gems/*/gems/ed25519-*/lib/ed25519_ref10.so
chrpath -d %{buildroot}/opt/puppetlabs/puppet/lib/ruby/gems/*/gems/sha3-*/ext/sha3/sha3_n.so
chrpath -d %{buildroot}/opt/puppetlabs/puppet/lib/ruby/gems/*/gems/sha3-*/lib/sha3_n.so

%files -n puppet-agent-extensions
%defattr(0644,root,root,0755)
%attr(0755,-,-) %{agentdir}/bin/trocla
%attr(0755,-,-) %{agentdir}/bin/iuid
%attr(0755,-,-) %{agentdir}/bin/rackup
%attr(0755,-,-) %{agentdir}/bin/tilt
%attr(0755,-,-) %{agentdir}/bin/nokogiri
%{agentgemdir}/specifications/*
%{agentgemdir}/extensions/*
%{agentgemdir}/gems/*

%files -n puppetserver-extensions
%defattr(0644,root,root,0755)
%{servergemdir}/*

%changelog

